==> haskell-syb-0.7.3-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 syb
version:              0.7.3
visibility:           public
id:                   syb-0.7.3-B3ujAx0b01UAjArJbq6cUd
key:                  syb-0.7.3-B3ujAx0b01UAjArJbq6cUd
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  9952cfca4d2760afb53da086c57a0429
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.3-B3ujAx0b01UAjArJbq6cUd
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-syb-0.7.3-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-syb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 syb
version:              0.7.3
visibility:           public
id:                   syb-0.7.3-8wamvTeFqIS3IMzaHn3GXS
key:                  syb-0.7.3-8wamvTeFqIS3IMzaHn3GXS
license:              BSD-3-Clause
maintainer:           Sergey Vinokurov <serg.foo@gmail.com>
author:               Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
stability:            provisional
homepage:             https://github.com/dreixel/syb
synopsis:             Scrap Your Boilerplate
description:
    This package contains the generics system described in the
    /Scrap Your Boilerplate/ papers (see
    <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
    It defines the @Data@ class of types permitting folding and unfolding
    of constructor applications, instances of this class for primitive
    types, and a variety of traversals.

category:             Generics
abi:                  c682d214281c8a8528e0fd50087873da
exposed:              True
exposed-modules:
    Data.Generics Data.Generics.Aliases Data.Generics.Basics
    Data.Generics.Builders Data.Generics.Instances
    Data.Generics.Schemes Data.Generics.Text Data.Generics.Twins
    Generics.SYB Generics.SYB.Aliases Generics.SYB.Basics
    Generics.SYB.Builders Generics.SYB.Instances Generics.SYB.Schemes
    Generics.SYB.Text Generics.SYB.Twins

import-dirs:          /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/syb-0.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-syb
hs-libraries:         HSsyb-0.7.3-8wamvTeFqIS3IMzaHn3GXS
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-syb/html/syb.haddock
haddock-html:         /usr/share/doc/haskell-syb/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
